@@ -40,7 +40,7 @@
 PYBIND11_MODULE(_muGrid, mod) {
   mod.doc() = "Python bindings to the µGrid library";
 
-  add_common(mod);
+  add_common_mugrid(mod);
   add_communicator(mod);
   add_field_classes(mod);
   add_state_field_classes(mod);
