@@ -313,6 +313,21 @@ namespace muGrid {
     return tmp;
   }
 
+  /* ---------------------------------------------------------------------- */
+  Unit Unit::force(const Int & new_tag) {
+    return mass(new_tag) * length(new_tag) / time(new_tag) / time(new_tag);
+  }
+
+  /* ---------------------------------------------------------------------- */
+  Unit Unit::stress(const Int & new_tag) {
+    return force(new_tag) / length(new_tag) / length(new_tag);
+  }
+
+  /* ---------------------------------------------------------------------- */
+  Unit Unit::strain(const Int & new_tag) {
+    return unitless(new_tag);
+  }
+
   /* ---------------------------------------------------------------------- */
   const UnitExponent & Unit::get_length() const { return this->units[0]; }
   /* ---------------------------------------------------------------------- */
@@ -362,6 +377,9 @@ namespace muGrid {
     return this->tag == other.tag and this->units == other.units;
   }
 
+  /* ---------------------------------------------------------------------- */
+  bool Unit::operator!=(const Unit & other) const { return !(*this == other); }
+
   /* ---------------------------------------------------------------------- */
   bool Unit::operator<(const Unit & other) const {
     if (this->tag != other.tag) {
